@@ -1,12 +1,27 @@
 package Audio::Nama::Globals;
 use Modern::Perl;
+
+# set aliases for common indices
 *bn = \%Audio::Nama::Bus::by_name;
 *tn = \%Audio::Nama::Track::by_name;
 *ti = \%Audio::Nama::Track::by_index;
+
 use Exporter;
 our @ISA = 'Exporter';
 our @EXPORT_OK = qw(
 
+$this_track
+$this_bus
+$this_op
+$this_param
+$this_mark
+$this_edit
+$prompt
+%tn
+%ti
+%bn
+$debug
+$debug2
 $ui
 $mode
 $file
@@ -23,24 +38,6 @@ $midi
 $help
 $mastering
 $project
-
-$this_track
-$this_bus
-$this_op
-$this_param
-$this_mark
-$this_edit
-$prompt
-%tn
-%ti
-%bn
-$debug
-$debug2
-@config_vars
-@persistent_vars
-@new_persistent_vars
-@project_config_vars
-
 @tracks_data
 @bus_data
 @groups_data
@@ -52,7 +49,10 @@ $debug2
 @global_effect_chain_data
 @project_effect_chain_data
 $this_track_name
-
+%track_comments
+%track_version_comments
+@persistent_vars
+@persistent_untracked_vars
 
 );
 
@@ -80,25 +80,29 @@ $project
 
 	)],
 
-	pronouns => [qw(
-						$this_track
-						$this_bus
-						$this_op
-						$this_param
-						$this_mark
-						$this_edit
-						%tn
-						%ti
-						%bn
-						$prompt
+	var_lists => [qw(
+
+						@persistent_vars
+						@persistent_untracked_vars
+						@global_effect_chain_vars
 	)],
 
-	var_types => [qw(
+	pronouns => [qw( 
+
+$this_track
+$this_bus
+$this_op
+$this_param
+$this_mark
+$this_edit
+$prompt
+%tn
+%ti
+%bn
+$debug
+$debug2
+
 
-						@config_vars
-						@persistent_vars
-						@new_persistent_vars
-						@global_effect_chain_vars
 	)],
 
 	serialize =>  [qw(
@@ -116,6 +120,16 @@ $project
 $this_track_name
 
 
+
+
+
+
+%track_comments
+%track_version_comments
+@persistent_vars
+@persistent_untracked_vars
+
+
 	)],
 );
 our $ui = 'bullwinkle';  # for testing
